@@ -4,9 +4,7 @@
  * Gnome Chemistry Utils
  * formula.cc 
  *
- * Copyright (C) 2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -465,6 +463,8 @@ void Formula::CalculateIsotopicPattern (IsotopicPattern &pattern)
 {
 	map<int,int>::iterator i, end = Raw.end ();
 	i = Raw.begin ();
+	if (i == end) // empty formula
+		return;
 	IsotopicPattern *pat, *pat0;
 	pat = Element::GetElement ((*i).first)->GetIsotopicPattern ((*i).second);
 	pattern.Copy (*pat);
